@@ -1,4 +1,4 @@
-#! /usr/bin/python
+#!/usr/bin/env python
 # domstart - make sure a given domU is running, if not start it
 
 import libvirt
@@ -21,7 +21,7 @@ dir = sys.argv[1]
 imgs = os.listdir(dir)
 
 conn = libvirt.open(None)
-if conn == None:
+if conn is None:
     print 'Failed to open connection to the hypervisor'
     sys.exit(1)
 
