@@ -123,7 +123,7 @@ virCapabilitiesFreeGuestMachine(virCapsGuestMachinePtr machine)
 static void
 virCapabilitiesFreeGuestDomain(virCapsGuestDomainPtr dom)
 {
-    int i;
+    size_t i;
     if (dom == NULL)
         return;
 
@@ -149,7 +149,7 @@ virCapabilitiesFreeGuestFeature(virCapsGuestFeaturePtr feature)
 static void
 virCapabilitiesFreeGuest(virCapsGuestPtr guest)
 {
-    int i;
+    size_t i;
     if (guest == NULL)
         return;
 
@@ -175,7 +175,7 @@ virCapabilitiesFreeGuest(virCapsGuestPtr guest)
 void
 virCapabilitiesFreeNUMAInfo(virCapsPtr caps)
 {
-    int i;
+    size_t i;
 
     for (i = 0; i < caps->host.nnumaCell; i++)
         virCapabilitiesFreeHostNUMACell(caps->host.numaCell[i]);
@@ -183,11 +183,25 @@ virCapabilitiesFreeNUMAInfo(virCapsPtr caps)
     caps->host.nnumaCell = 0;
 }
 
+static void
+virCapabilitiesClearSecModel(virCapsHostSecModelPtr secmodel)
+{
+    size_t i;
+    for (i = 0; i < secmodel->nlabels; i++) {
+        VIR_FREE(secmodel->labels[i].type);
+        VIR_FREE(secmodel->labels[i].label);
+    }
+
+    VIR_FREE(secmodel->labels);
+    VIR_FREE(secmodel->model);
+    VIR_FREE(secmodel->doi);
+}
+
 static void
 virCapabilitiesDispose(void *object)
 {
     virCapsPtr caps = object;
-    int i;
+    size_t i;
 
     for (i = 0; i < caps->nguests; i++)
         virCapabilitiesFreeGuest(caps->guests[i]);
@@ -204,8 +218,7 @@ virCapabilitiesDispose(void *object)
     VIR_FREE(caps->host.migrateTrans);
 
     for (i = 0; i < caps->host.nsecModels; i++) {
-        VIR_FREE(caps->host.secModels[i].model);
-        VIR_FREE(caps->host.secModels[i].doi);
+        virCapabilitiesClearSecModel(&caps->host.secModels[i]);
     }
     VIR_FREE(caps->host.secModels);
 
@@ -327,7 +340,7 @@ virCapsGuestMachinePtr *
 virCapabilitiesAllocMachines(const char *const *names, int nnames)
 {
     virCapsGuestMachinePtr *machines;
-    int i;
+    size_t i;
 
     if (VIR_ALLOC_N(machines, nnames) < 0)
         return NULL;
@@ -353,7 +366,7 @@ void
 virCapabilitiesFreeMachines(virCapsGuestMachinePtr *machines,
                             int nmachines)
 {
-    int i;
+    size_t i;
     if (!machines)
         return;
     for (i = 0; i < nmachines && machines[i]; i++) {
@@ -506,6 +519,44 @@ virCapabilitiesAddGuestFeature(virCapsGuestPtr guest,
     return NULL;
 }
 
+/**
+ * virCapabilitiesHostSecModelAddBaseLabel
+ * @secmodel: Security model to add a base label for
+ * @type: virtualization type
+ * @label: base label
+ *
+ * Returns non-zero on error.
+ */
+extern int
+virCapabilitiesHostSecModelAddBaseLabel(virCapsHostSecModelPtr secmodel,
+                                        const char *type,
+                                        const char *label)
+{
+    char *t = NULL, *l = NULL;
+
+    if (type == NULL || label == NULL)
+        return -1;
+
+    if (VIR_STRDUP(t, type) < 0)
+        goto no_memory;
+
+    if (VIR_STRDUP(l, label) < 0)
+        goto no_memory;
+
+    if (VIR_EXPAND_N(secmodel->labels, secmodel->nlabels, 1) < 0)
+        goto no_memory;
+
+    secmodel->labels[secmodel->nlabels - 1].type = t;
+    secmodel->labels[secmodel->nlabels - 1].label = l;
+
+    return 0;
+
+no_memory:
+    VIR_FREE(l);
+    VIR_FREE(t);
+    return -1;
+}
+
 /**
  * virCapabilitiesSupportsGuestArch:
  * @caps: capabilities to query
@@ -518,7 +569,7 @@ extern int
 virCapabilitiesSupportsGuestArch(virCapsPtr caps,
                                  virArch arch)
 {
-    int i;
+    size_t i;
     for (i = 0; i < caps->nguests; i++) {
         if (caps->guests[i]->arch.id == arch)
             return 1;
@@ -539,7 +590,7 @@ extern int
 virCapabilitiesSupportsGuestOSType(virCapsPtr caps,
                                    const char *ostype)
 {
-    int i;
+    size_t i;
     for (i = 0; i < caps->nguests; i++) {
         if (STREQ(caps->guests[i]->ostype, ostype))
             return 1;
@@ -562,7 +613,7 @@ virCapabilitiesSupportsGuestOSTypeArch(virCapsPtr caps,
                                        const char *ostype,
                                        virArch arch)
 {
-    int i;
+    size_t i;
     for (i = 0; i < caps->nguests; i++) {
         if (STREQ(caps->guests[i]->ostype, ostype) &&
             caps->guests[i]->arch.id == arch)
@@ -585,7 +636,7 @@ virCapabilitiesDefaultGuestArch(virCapsPtr caps,
                                 const char *ostype,
                                 const char *domain)
 {
-    int i, j;
+    size_t i, j;
 
     /* First try to find one matching host arch */
     for (i = 0; i < caps->nguests; i++) {
@@ -628,11 +679,11 @@ virCapabilitiesDefaultGuestMachine(virCapsPtr caps,
                                    virArch arch,
                                    const char *domain)
 {
-    int i;
+    size_t i;
 
     for (i = 0; i < caps->nguests; i++) {
         virCapsGuestPtr guest = caps->guests[i];
-        int j;
+        size_t j;
 
         if (!STREQ(guest->ostype, ostype) ||
             guest->arch.id != arch)
@@ -674,7 +725,7 @@ virCapabilitiesDefaultGuestEmulator(virCapsPtr caps,
                                     virArch arch,
                                     const char *domain)
 {
-    int i, j;
+    size_t i, j;
     for (i = 0; i < caps->nguests; i++) {
         char *emulator;
         if (STREQ(caps->guests[i]->ostype, ostype) &&
@@ -697,8 +748,8 @@ virCapabilitiesFormatNUMATopology(virBufferPtr xml,
                                   size_t ncells,
                                   virCapsHostNUMACellPtr *cells)
 {
-    int i;
-    int j;
+    size_t i;
+    size_t j;
     char *siblings;
 
     virBufferAddLit(xml, "    <topology>\n");
@@ -754,7 +805,7 @@ char *
 virCapabilitiesFormatXML(virCapsPtr caps)
 {
     virBuffer xml = VIR_BUFFER_INITIALIZER;
-    int i, j, k;
+    size_t i, j, k;
     char host_uuid[VIR_UUID_STRING_BUFLEN];
 
     virBufferAddLit(&xml, "<capabilities>\n\n");
@@ -826,6 +877,11 @@ virCapabilitiesFormatXML(virCapsPtr caps)
                           caps->host.secModels[i].model);
         virBufferAsprintf(&xml, "      <doi>%s</doi>\n",
                           caps->host.secModels[i].doi);
+        for (j = 0; j < caps->host.secModels[i].nlabels; j++) {
+            virBufferAsprintf(&xml, "      <baselabel type='%s'>%s</baselabel>\n",
+                              caps->host.secModels[i].labels[j].type,
+                              caps->host.secModels[i].labels[j].label);
+        }
         virBufferAddLit(&xml, "    </secmodel>\n");
     }
 
@@ -853,6 +909,8 @@ virCapabilitiesFormatXML(virCapsPtr caps)
             virBufferAddLit(&xml, "      <machine");
             if (machine->canonical)
                 virBufferAsprintf(&xml, " canonical='%s'", machine->canonical);
+            if (machine->maxCpus > 0)
+                virBufferAsprintf(&xml, " maxCpus='%d'", machine->maxCpus);
             virBufferAsprintf(&xml, ">%s</machine>\n", machine->name);
         }
 
@@ -871,6 +929,8 @@ virCapabilitiesFormatXML(virCapsPtr caps)
                 virBufferAddLit(&xml, "        <machine");
                 if (machine->canonical)
                     virBufferAsprintf(&xml, " canonical='%s'", machine->canonical);
+                if (machine->maxCpus > 0)
+                    virBufferAsprintf(&xml, " maxCpus='%d'", machine->maxCpus);
                 virBufferAsprintf(&xml, ">%s</machine>\n", machine->name);
             }
             virBufferAddLit(&xml, "      </domain>\n");
@@ -912,3 +972,67 @@ virCapabilitiesFormatXML(virCapsPtr caps)
 
     return virBufferContentAndReset(&xml);
 }
+
+/* get the maximum ID of cpus in the host */
+static unsigned int
+virCapabilitiesGetHostMaxcpu(virCapsPtr caps)
+{
+    unsigned int maxcpu = 0;
+    size_t node;
+    size_t cpu;
+
+    for (node = 0; node < caps->host.nnumaCell; node++) {
+        virCapsHostNUMACellPtr cell = caps->host.numaCell[node];
+
+        for (cpu = 0; cpu < cell->ncpus; cpu++) {
+            if (cell->cpus[cpu].id > maxcpu)
+                maxcpu = cell->cpus[cpu].id;
+        }
+    }
+
+    return maxcpu;
+}
+
+/* set cpus of a numa node in the bitmask */
+static int
+virCapabilitiesGetCpusForNode(virCapsPtr caps,
+                              size_t node,
+                              virBitmapPtr cpumask)
+{
+    virCapsHostNUMACellPtr cell = caps->host.numaCell[node];
+    size_t cpu;
+
+    for (cpu = 0; cpu < cell->ncpus; cpu++) {
+        if (virBitmapSetBit(cpumask, cell->cpus[cpu].id) < 0) {
+            virReportError(VIR_ERR_INTERNAL_ERROR,
+                           _("Cpu '%u' in node '%zu' is out of range "
+                             "of the provided bitmap"),
+                           cell->cpus[cpu].id, node);
+            return -1;
+        }
+    }
+
+    return 0;
+}
+
+virBitmapPtr
+virCapabilitiesGetCpusForNodemask(virCapsPtr caps,
+                                  virBitmapPtr nodemask)
+{
+    virBitmapPtr ret = NULL;
+    unsigned int maxcpu = virCapabilitiesGetHostMaxcpu(caps);
+    ssize_t node = -1;
+
+    if (!(ret = virBitmapNew(maxcpu + 1)))
+        return NULL;
+
+
+    while ((node = virBitmapNextSetBit(nodemask, node)) >= 0) {
+        if (virCapabilitiesGetCpusForNode(caps, node, ret) < 0) {
+            virBitmapFree(ret);
+            return NULL;
+        }
+    }
+
+    return ret;
+}
