@@ -1,7 +1,7 @@
 /*
- * cpu_conf.h: CPU XML handling
+ * cpu_conf.c: CPU XML handling
  *
- * Copyright (C) 2009-2011 Red Hat, Inc.
+ * Copyright (C) 2009-2013 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -60,7 +60,7 @@ VIR_ENUM_IMPL(virCPUFeaturePolicy, VIR_CPU_FEATURE_LAST,
 void ATTRIBUTE_NONNULL(1)
 virCPUDefFreeModel(virCPUDefPtr def)
 {
-    unsigned int i;
+    size_t i;
 
     VIR_FREE(def->model);
     VIR_FREE(def->vendor);
@@ -74,7 +74,7 @@ virCPUDefFreeModel(virCPUDefPtr def)
 void
 virCPUDefFree(virCPUDefPtr def)
 {
-    unsigned int i;
+    size_t i;
 
     if (!def)
         return;
@@ -94,16 +94,16 @@ virCPUDefFree(virCPUDefPtr def)
 
 int ATTRIBUTE_NONNULL(1) ATTRIBUTE_NONNULL(2)
 virCPUDefCopyModel(virCPUDefPtr dst,
-                   const virCPUDefPtr src,
+                   const virCPUDef *src,
                    bool resetPolicy)
 {
-    unsigned int i;
+    size_t i;
 
     if (VIR_STRDUP(dst->model, src->model) < 0 ||
         VIR_STRDUP(dst->vendor, src->vendor) < 0 ||
         VIR_STRDUP(dst->vendor_id, src->vendor_id) < 0 ||
         VIR_ALLOC_N(dst->features, src->nfeatures) < 0)
-        goto no_memory;
+        return -1;
     dst->nfeatures_max = dst->nfeatures = src->nfeatures;
 
     for (i = 0; i < dst->nfeatures; i++) {
@@ -123,24 +123,17 @@ virCPUDefCopyModel(virCPUDefPtr dst,
     }
 
     return 0;
-
-no_memory:
-    virReportOOMError();
-    return -1;
 }
 
 virCPUDefPtr
-virCPUDefCopy(const virCPUDefPtr cpu)
+virCPUDefCopy(const virCPUDef *cpu)
 {
     virCPUDefPtr copy;
-    unsigned int i;
+    size_t i;
 
-    if (!cpu)
+    if (!cpu || VIR_ALLOC(copy) < 0)
         return NULL;
 
-    if (VIR_ALLOC(copy) < 0)
-        goto no_memory;
-
     copy->type = cpu->type;
     copy->mode = cpu->mode;
     copy->match = cpu->match;
@@ -155,7 +148,7 @@ virCPUDefCopy(const virCPUDefPtr cpu)
 
     if (cpu->ncells) {
         if (VIR_ALLOC_N(copy->cells, cpu->ncells) < 0)
-            goto no_memory;
+            goto error;
         copy->ncells_max = copy->ncells = cpu->ncells;
 
         for (i = 0; i < cpu->ncells; i++) {
@@ -165,7 +158,7 @@ virCPUDefCopy(const virCPUDefPtr cpu)
             copy->cells[i].cpumask = virBitmapNewCopy(cpu->cells[i].cpumask);
 
             if (!copy->cells[i].cpumask)
-                goto no_memory;
+                goto error;
 
             if (VIR_STRDUP(copy->cells[i].cpustr, cpu->cells[i].cpustr) < 0)
                 goto error;
@@ -175,37 +168,32 @@ virCPUDefCopy(const virCPUDefPtr cpu)
 
     return copy;
 
-no_memory:
-    virReportOOMError();
 error:
     virCPUDefFree(copy);
     return NULL;
 }
 
 virCPUDefPtr
-virCPUDefParseXML(const xmlNodePtr node,
+virCPUDefParseXML(xmlNodePtr node,
                   xmlXPathContextPtr ctxt,
                   enum virCPUType mode)
 {
     virCPUDefPtr def;
     xmlNodePtr *nodes = NULL;
     int n;
-    unsigned int i;
+    size_t i;
     char *cpuMode;
     char *fallback = NULL;
     char *vendor_id = NULL;
 
     if (!xmlStrEqual(node->name, BAD_CAST "cpu")) {
-        virReportError(VIR_ERR_INTERNAL_ERROR,
-                       "%s",
+        virReportError(VIR_ERR_XML_ERROR, "%s",
                        _("XML does not contain expected 'cpu' element"));
         return NULL;
     }
 
-    if (VIR_ALLOC(def) < 0) {
-        virReportOOMError();
+    if (VIR_ALLOC(def) < 0)
         return NULL;
-    }
 
     if (mode == VIR_CPU_TYPE_AUTO) {
         if (virXPathBoolean("boolean(./arch)", ctxt)) {
@@ -233,7 +221,7 @@ virCPUDefParseXML(const xmlNodePtr node,
             def->mode = virCPUModeTypeFromString(cpuMode);
 
             if (def->mode < 0) {
-                virReportError(VIR_ERR_INTERNAL_ERROR,
+                virReportError(VIR_ERR_XML_ERROR,
                                _("Invalid mode attribute '%s'"),
                                cpuMode);
                 VIR_FREE(cpuMode);
@@ -261,7 +249,7 @@ virCPUDefParseXML(const xmlNodePtr node,
             VIR_FREE(match);
 
             if (def->match < 0) {
-                virReportError(VIR_ERR_INTERNAL_ERROR, "%s",
+                virReportError(VIR_ERR_XML_ERROR, "%s",
                                _("Invalid match attribute for CPU "
                                  "specification"));
                 goto error;
@@ -272,12 +260,12 @@ virCPUDefParseXML(const xmlNodePtr node,
     if (def->type == VIR_CPU_TYPE_HOST) {
         char *arch = virXPathString("string(./arch[1])", ctxt);
         if (!arch) {
-            virReportError(VIR_ERR_INTERNAL_ERROR,
-                           "%s", _("Missing CPU architecture"));
+            virReportError(VIR_ERR_XML_ERROR, "%s",
+                           _("Missing CPU architecture"));
             goto error;
         }
         if ((def->arch = virArchFromString(arch)) == VIR_ARCH_NONE) {
-            virReportError(VIR_ERR_INTERNAL_ERROR,
+            virReportError(VIR_ERR_XML_ERROR,
                            _("Unknown architecture %s"), arch);
             VIR_FREE(arch);
             goto error;
@@ -287,8 +275,8 @@ virCPUDefParseXML(const xmlNodePtr node,
 
     if (!(def->model = virXPathString("string(./model[1])", ctxt)) &&
         def->type == VIR_CPU_TYPE_HOST) {
-        virReportError(VIR_ERR_INTERNAL_ERROR,
-                       "%s", _("Missing CPU model name"));
+        virReportError(VIR_ERR_XML_ERROR, "%s",
+                        _("Missing CPU model name"));
         goto error;
     }
 
@@ -326,8 +314,8 @@ virCPUDefParseXML(const xmlNodePtr node,
 
     def->vendor = virXPathString("string(./vendor[1])", ctxt);
     if (def->vendor && !def->model) {
-        virReportError(VIR_ERR_INTERNAL_ERROR,
-                       "%s", _("CPU vendor specified without CPU model"));
+        virReportError(VIR_ERR_XML_ERROR, "%s",
+                       _("CPU vendor specified without CPU model"));
         goto error;
     }
 
@@ -338,7 +326,7 @@ virCPUDefParseXML(const xmlNodePtr node,
         ret = virXPathULong("string(./topology[1]/@sockets)",
                             ctxt, &ul);
         if (ret < 0) {
-            virReportError(VIR_ERR_INTERNAL_ERROR, "%s",
+            virReportError(VIR_ERR_XML_ERROR, "%s",
                            _("Missing 'sockets' attribute in CPU topology"));
             goto error;
         }
@@ -347,7 +335,7 @@ virCPUDefParseXML(const xmlNodePtr node,
         ret = virXPathULong("string(./topology[1]/@cores)",
                             ctxt, &ul);
         if (ret < 0) {
-            virReportError(VIR_ERR_INTERNAL_ERROR, "%s",
+            virReportError(VIR_ERR_XML_ERROR, "%s",
                            _("Missing 'cores' attribute in CPU topology"));
             goto error;
         }
@@ -356,26 +344,25 @@ virCPUDefParseXML(const xmlNodePtr node,
         ret = virXPathULong("string(./topology[1]/@threads)",
                             ctxt, &ul);
         if (ret < 0) {
-            virReportError(VIR_ERR_INTERNAL_ERROR, "%s",
+            virReportError(VIR_ERR_XML_ERROR, "%s",
                            _("Missing 'threads' attribute in CPU topology"));
             goto error;
         }
         def->threads = (unsigned int) ul;
 
         if (!def->sockets || !def->cores || !def->threads) {
-            virReportError(VIR_ERR_INTERNAL_ERROR,
-                           "%s", _("Invalid CPU topology"));
+            virReportError(VIR_ERR_XML_ERROR, "%s",
+                           _("Invalid CPU topology"));
             goto error;
         }
     }
 
-    n = virXPathNodeSet("./feature", ctxt, &nodes);
-    if (n < 0)
+    if ((n = virXPathNodeSet("./feature", ctxt, &nodes)) < 0)
         goto error;
 
     if (n > 0) {
-        if (!def->model) {
-            virReportError(VIR_ERR_INTERNAL_ERROR, "%s",
+        if (!def->model && def->mode != VIR_CPU_MODE_HOST_MODEL) {
+            virReportError(VIR_ERR_XML_ERROR, "%s",
                            _("Non-empty feature list specified without "
                              "CPU model"));
             goto error;
@@ -383,14 +370,15 @@ virCPUDefParseXML(const xmlNodePtr node,
 
         if (VIR_RESIZE_N(def->features, def->nfeatures_max,
                          def->nfeatures, n) < 0)
-            goto no_memory;
+            goto error;
+
         def->nfeatures = n;
     }
 
     for (i = 0; i < n; i++) {
         char *name;
         int policy; /* enum virDomainCPUFeaturePolicy */
-        unsigned int j;
+        size_t j;
 
         if (def->type == VIR_CPU_TYPE_GUEST) {
             char *strpolicy;
@@ -403,8 +391,8 @@ virCPUDefParseXML(const xmlNodePtr node,
             VIR_FREE(strpolicy);
 
             if (policy < 0) {
-                virReportError(VIR_ERR_INTERNAL_ERROR,
-                               "%s", _("Invalid CPU feature policy"));
+                virReportError(VIR_ERR_XML_ERROR, "%s",
+                               _("Invalid CPU feature policy"));
                 goto error;
             }
         } else {
@@ -413,14 +401,14 @@ virCPUDefParseXML(const xmlNodePtr node,
 
         if (!(name = virXMLPropString(nodes[i], "name")) || *name == 0) {
             VIR_FREE(name);
-            virReportError(VIR_ERR_INTERNAL_ERROR,
-                           "%s", _("Invalid CPU feature name"));
+            virReportError(VIR_ERR_XML_ERROR, "%s",
+                           _("Invalid CPU feature name"));
             goto error;
         }
 
         for (j = 0; j < i; j++) {
             if (STREQ(name, def->features[j].name)) {
-                virReportError(VIR_ERR_INTERNAL_ERROR,
+                virReportError(VIR_ERR_XML_ERROR,
                                _("CPU feature `%s' specified more than once"),
                                name);
                 VIR_FREE(name);
@@ -436,14 +424,14 @@ virCPUDefParseXML(const xmlNodePtr node,
         VIR_FREE(nodes);
         n = virXPathNodeSet("./numa[1]/cell", ctxt, &nodes);
         if (n <= 0) {
-            virReportError(VIR_ERR_INTERNAL_ERROR,
-                           "%s", _("NUMA topology defined without NUMA cells"));
+            virReportError(VIR_ERR_XML_ERROR, "%s",
+                           _("NUMA topology defined without NUMA cells"));
             goto error;
         }
 
         if (VIR_RESIZE_N(def->cells, def->ncells_max,
                          def->ncells, n) < 0)
-            goto no_memory;
+            goto error;
 
         def->ncells = n;
 
@@ -454,8 +442,8 @@ virCPUDefParseXML(const xmlNodePtr node,
             def->cells[i].cellid = i;
             cpus = virXMLPropString(nodes[i], "cpus");
             if (!cpus) {
-                virReportError(VIR_ERR_INTERNAL_ERROR,
-                               "%s", _("Missing 'cpus' attribute in NUMA cell"));
+                virReportError(VIR_ERR_XML_ERROR, "%s",
+                               _("Missing 'cpus' attribute in NUMA cell"));
                 goto error;
             }
             def->cells[i].cpustr = cpus;
@@ -468,15 +456,15 @@ virCPUDefParseXML(const xmlNodePtr node,
 
             memory = virXMLPropString(nodes[i], "memory");
             if (!memory) {
-                virReportError(VIR_ERR_INTERNAL_ERROR,
-                               "%s", _("Missing 'memory' attribute in NUMA cell"));
+                virReportError(VIR_ERR_XML_ERROR, "%s",
+                               _("Missing 'memory' attribute in NUMA cell"));
                 goto error;
             }
 
             ret  = virStrToLong_ui(memory, NULL, 10, &def->cells[i].mem);
             if (ret == -1) {
-                virReportError(VIR_ERR_INTERNAL_ERROR,
-                               "%s", _("Invalid 'memory' attribute in NUMA cell"));
+                virReportError(VIR_ERR_XML_ERROR, "%s",
+                               _("Invalid 'memory' attribute in NUMA cell"));
                 VIR_FREE(memory);
                 goto error;
             }
@@ -490,9 +478,6 @@ cleanup:
     VIR_FREE(nodes);
     return def;
 
-no_memory:
-    virReportOOMError();
-
 error:
     virCPUDefFree(def);
     def = NULL;
@@ -576,7 +561,7 @@ virCPUDefFormatBuf(virBufferPtr buf,
                    virCPUDefPtr def,
                    unsigned int flags)
 {
-    unsigned int i;
+    size_t i;
     bool formatModel;
     bool formatFallback;
 
@@ -589,9 +574,11 @@ virCPUDefFormatBuf(virBufferPtr buf,
                       (def->mode == VIR_CPU_MODE_HOST_MODEL ||
                        (def->mode == VIR_CPU_MODE_CUSTOM && def->model)));
 
-    if (!def->model && def->nfeatures) {
-        virReportError(VIR_ERR_INTERNAL_ERROR,
-                       "%s", _("Non-empty feature list specified without CPU model"));
+    if (!def->model &&
+        def->mode != VIR_CPU_MODE_HOST_MODEL &&
+        def->nfeatures) {
+        virReportError(VIR_ERR_INTERNAL_ERROR, "%s",
+                       _("Non-empty feature list specified without CPU model"));
         return -1;
     }
 
@@ -629,32 +616,30 @@ virCPUDefFormatBuf(virBufferPtr buf,
         virBufferAddLit(buf, "/>\n");
     }
 
-    if (formatModel) {
-        for (i = 0; i < def->nfeatures; i++) {
-            virCPUFeatureDefPtr feature = def->features + i;
+    for (i = 0; i < def->nfeatures; i++) {
+        virCPUFeatureDefPtr feature = def->features + i;
 
-            if (!feature->name) {
+        if (!feature->name) {
+            virReportError(VIR_ERR_INTERNAL_ERROR, "%s",
+                           _("Missing CPU feature name"));
+            return -1;
+        }
+
+        if (def->type == VIR_CPU_TYPE_GUEST) {
+            const char *policy;
+
+            policy = virCPUFeaturePolicyTypeToString(feature->policy);
+            if (!policy) {
                 virReportError(VIR_ERR_INTERNAL_ERROR,
-                               "%s", _("Missing CPU feature name"));
+                               _("Unexpected CPU feature policy %d"),
+                               feature->policy);
                 return -1;
             }
-
-            if (def->type == VIR_CPU_TYPE_GUEST) {
-                const char *policy;
-
-                policy = virCPUFeaturePolicyTypeToString(feature->policy);
-                if (!policy) {
-                    virReportError(VIR_ERR_INTERNAL_ERROR,
-                                   _("Unexpected CPU feature policy %d"),
-                                   feature->policy);
-                    return -1;
-                }
-                virBufferAsprintf(buf, "<feature policy='%s' name='%s'/>\n",
-                                  policy, feature->name);
-            } else {
-                virBufferAsprintf(buf, "<feature name='%s'/>\n",
-                                  feature->name);
-            }
+            virBufferAsprintf(buf, "<feature policy='%s' name='%s'/>\n",
+                              policy, feature->name);
+        } else {
+            virBufferAsprintf(buf, "<feature name='%s'/>\n",
+                              feature->name);
         }
     }
 
@@ -671,28 +656,35 @@ virCPUDefFormatBuf(virBufferPtr buf,
     return 0;
 }
 
-
-int
-virCPUDefAddFeature(virCPUDefPtr def,
-                    const char *name,
-                    int policy)
+static int
+virCPUDefUpdateFeatureInternal(virCPUDefPtr def,
+                               const char *name,
+                               int policy,
+                               bool update)
 {
-    int i;
+    size_t i;
+
+    if (def->type == VIR_CPU_TYPE_HOST)
+        policy = -1;
 
     for (i = 0; i < def->nfeatures; i++) {
         if (STREQ(name, def->features[i].name)) {
+            if (update) {
+                def->features[i].policy = policy;
+                return 0;
+            }
+
             virReportError(VIR_ERR_INTERNAL_ERROR,
-                           _("CPU feature `%s' specified more than once"), name);
+                           _("CPU feature `%s' specified more than once"),
+                           name);
+
             return -1;
         }
     }
 
     if (VIR_RESIZE_N(def->features, def->nfeatures_max,
                      def->nfeatures, 1) < 0)
-        goto no_memory;
-
-    if (def->type == VIR_CPU_TYPE_HOST)
-        policy = -1;
+        return -1;
 
     if (VIR_STRDUP(def->features[def->nfeatures].name, name) < 0)
         return -1;
@@ -701,10 +693,22 @@ virCPUDefAddFeature(virCPUDefPtr def,
     def->nfeatures++;
 
     return 0;
+}
 
-no_memory:
-    virReportOOMError();
-    return -1;
+int
+virCPUDefUpdateFeature(virCPUDefPtr def,
+                       const char *name,
+                       int policy)
+{
+    return virCPUDefUpdateFeatureInternal(def, name, policy, true);
+}
+
+int
+virCPUDefAddFeature(virCPUDefPtr def,
+                    const char *name,
+                    int policy)
+{
+    return virCPUDefUpdateFeatureInternal(def, name, policy, false);
 }
 
 bool
@@ -712,7 +716,7 @@ virCPUDefIsEqual(virCPUDefPtr src,
                  virCPUDefPtr dst)
 {
     bool identical = false;
-    int i;
+    size_t i;
 
     if (!src && !dst)
         return true;
