@@ -26,7 +26,8 @@
 
 # include <stdint.h>
 
-struct cpuX86cpuid {
+typedef struct _virCPUx86CPUID virCPUx86CPUID;
+struct _virCPUx86CPUID {
     uint32_t function;
     uint32_t eax;
     uint32_t ebx;
@@ -37,11 +38,12 @@ struct cpuX86cpuid {
 # define CPUX86_BASIC    0x0
 # define CPUX86_EXTENDED 0x80000000
 
-struct cpuX86Data {
+typedef struct _virCPUx86Data virCPUx86Data;
+struct _virCPUx86Data {
     size_t basic_len;
-    struct cpuX86cpuid *basic;
+    virCPUx86CPUID *basic;
     size_t extended_len;
-    struct cpuX86cpuid *extended;
+    virCPUx86CPUID *extended;
 };
 
 #endif /* __VIR_CPU_X86_DATA_H__ */
