@@ -408,7 +408,8 @@ gather_capabilities(LibHalContext *ctx, const char *udi,
     char *bus_name = NULL;
     virNodeDevCapsDefPtr caps = NULL;
     char **hal_cap_names = NULL;
-    int rv, i;
+    int rv;
+    size_t i;
 
     if (STREQ(udi, "/org/freedesktop/Hal/devices/computer")) {
         rv = gather_capability(ctx, udi, "system", &caps);
@@ -632,7 +633,8 @@ nodeStateInitialize(bool privileged ATTRIBUTE_UNUSED,
 {
     LibHalContext *hal_ctx = NULL;
     char **udi = NULL;
-    int num_devs, i;
+    int num_devs;
+    size_t i;
     int ret = -1;
     DBusConnection *sysbus;
     DBusError err;
@@ -650,6 +652,7 @@ nodeStateInitialize(bool privileged ATTRIBUTE_UNUSED,
     }
     nodeDeviceLock(driverState);
 
+    dbus_error_init(&err);
     if (!(sysbus = virDBusGetSystemBus())) {
         virErrorPtr verr = virGetLastError();
         VIR_ERROR(_("DBus not available, disabling HAL driver: %s"),
@@ -658,7 +661,6 @@ nodeStateInitialize(bool privileged ATTRIBUTE_UNUSED,
         goto failure;
     }
 
-    dbus_error_init(&err);
     hal_ctx = libhal_ctx_new();
     if (hal_ctx == NULL) {
         VIR_ERROR(_("libhal_ctx_new returned NULL"));
@@ -750,7 +752,8 @@ nodeStateReload(void)
 {
     DBusError err;
     char **udi = NULL;
-    int num_devs, i;
+    int num_devs;
+    size_t i;
     LibHalContext *hal_ctx;
 
     VIR_INFO("Reloading HAL device state");
