@@ -1538,8 +1538,8 @@ storageVolCreateXML(virStoragePoolPtr obj,
         goto cleanup;
 
     if (virStorageVolDefFindByName(pool, voldef->name)) {
-        virReportError(VIR_ERR_NO_STORAGE_VOL,
-                       _("storage vol '%s' already exists"), voldef->name);
+        virReportError(VIR_ERR_STORAGE_VOL_EXIST,
+                       _("'%s'"), voldef->name);
         goto cleanup;
     }
 
