@@ -123,6 +123,7 @@ VIR_ENUM_IMPL(virErrorDomain, VIR_ERR_DOMAIN_LAST,
               "Cgroup",
 
               "Access Manager", /* 55 */
+              "Systemd",
     )
 
 
@@ -209,7 +210,7 @@ virLastErrorObject(void)
     virErrorPtr err;
     err = virThreadLocalGet(&virLastErr);
     if (!err) {
-        if (VIR_ALLOC(err) < 0)
+        if (VIR_ALLOC_QUIET(err) < 0)
             return NULL;
         if (virThreadLocalSet(&virLastErr, err) < 0)
             VIR_FREE(err);
@@ -330,7 +331,7 @@ virSaveLastError(void)
     virErrorPtr to;
     int saved_errno = errno;
 
-    if (VIR_ALLOC(to) < 0)
+    if (VIR_ALLOC_QUIET(to) < 0)
         return NULL;
 
     virCopyLastError(to);
@@ -674,7 +675,7 @@ virRaiseErrorFull(const char *filename ATTRIBUTE_UNUSED,
     } else {
         va_list ap;
         va_start(ap, fmt);
-        ignore_value(virVasprintf(&str, fmt, ap));
+        ignore_value(virVasprintfQuiet(&str, fmt, ap));
         va_end(ap);
     }
 
@@ -729,7 +730,7 @@ virErrorMsg(virErrorNumber error, const char *info)
             return NULL;
         case VIR_ERR_INTERNAL_ERROR:
             if (info != NULL)
-              errmsg = _("internal error %s");
+              errmsg = _("internal error: %s");
             else
               errmsg = _("internal error");
             break;
@@ -1003,6 +1004,12 @@ virErrorMsg(virErrorNumber error, const char *info)
             else
                 errmsg = _("Storage volume not found: %s");
             break;
+        case VIR_ERR_STORAGE_VOL_EXIST:
+            if (info == NULL)
+                errmsg = _("this storage volume exists already");
+            else
+                errmsg = _("storage volume %s exists already");
+            break;
         case VIR_ERR_STORAGE_PROBE_FAILED:
             if (info == NULL)
                 errmsg = _("Storage pool probe failed");
@@ -1243,6 +1250,12 @@ virErrorMsg(virErrorNumber error, const char *info)
             else
                 errmsg = _("access denied: %s");
             break;
+        case VIR_ERR_DBUS_SERVICE:
+            if (info == NULL)
+                errmsg = _("error from service");
+            else
+                errmsg = _("error from service: %s");
+            break;
     }
     return errmsg;
 }
@@ -1397,3 +1410,51 @@ void virSetErrorLogPriorityFunc(virErrorLogPriorityFunc func)
 {
     virErrorLogPriorityFilter = func;
 }
+
+
+/**
+ * virErrorSetErrnoFromLastError:
+ *
+ * If the last error had a code of VIR_ERR_SYSTEM_ERROR
+ * then set errno to the value saved in the error object.
+ *
+ * If the last error had a code of VIR_ERR_NO_MEMORY
+ * then set errno to ENOMEM
+ *
+ * Otherwise set errno to EIO.
+ */
+void virErrorSetErrnoFromLastError(void)
+{
+    virErrorPtr err = virGetLastError();
+    if (err && err->code == VIR_ERR_SYSTEM_ERROR) {
+        errno = err->int1;
+    } else if (err && err->code == VIR_ERR_NO_MEMORY) {
+        errno = ENOMEM;
+    } else {
+        errno = EIO;
+    }
+}
+
+
+/**
+ * virLastErrorIsSystemErrno:
+ * @errnum: the errno value
+ *
+ * Check if the last error reported is a system
+ * error with the specific errno value.
+ *
+ * If @errnum is zero, any system error will pass.
+ *
+ * Returns true if the last error was a system error with errno == @errnum
+ */
+bool virLastErrorIsSystemErrno(int errnum)
+{
+    virErrorPtr err = virGetLastError();
+    if (!err)
+        return false;
+    if (err->code != VIR_ERR_SYSTEM_ERROR)
+        return false;
+    if (errnum != 0 && err->int1 != errnum)
+        return false;
+    return true;
+}
