@@ -112,6 +112,8 @@ enum {
     VIR_STORAGE_FILE_SHFS_GFS2 = (1 << 1),
     VIR_STORAGE_FILE_SHFS_OCFS = (1 << 2),
     VIR_STORAGE_FILE_SHFS_AFS = (1 << 3),
+    VIR_STORAGE_FILE_SHFS_SMB = (1 << 4),
+    VIR_STORAGE_FILE_SHFS_CIFS = (1 << 5),
 };
 
 int virStorageFileIsSharedFS(const char *path);
