@@ -138,7 +138,7 @@ mymain(void)
 #define DO_TEST_FULL(name, cmd, doc, expect, pass)                  \
     do {                                                            \
         struct testInfo info = { doc, expect, pass };               \
-        if (virtTestRun(name, 1, testJSON ## cmd, &info) < 0)       \
+        if (virtTestRun(name, testJSON ## cmd, &info) < 0)          \
             ret = -1;                                               \
     } while (0)
 
