@@ -191,10 +191,10 @@ mymain(void)
 {
     int ret = 0;
 
-    if (virtTestRun("Test alloc all", 1, testAllocAll, NULL) < 0)
+    if (virtTestRun("Test alloc all", testAllocAll, NULL) < 0)
         ret = -1;
 
-    if (virtTestRun("Test alloc reuse", 1, testAllocReuse, NULL) < 0)
+    if (virtTestRun("Test alloc reuse", testAllocReuse, NULL) < 0)
         ret = -1;
 
     return ret==0 ? EXIT_SUCCESS : EXIT_FAILURE;
