@@ -48,7 +48,7 @@
 #include <libxml/xpath.h>
 #include <libxml/xmlsave.h>
 
-#ifdef HAVE_READLINE_READLINE_H
+#if WITH_READLINE
 # include <readline/readline.h>
 # include <readline/history.h>
 #endif
@@ -885,6 +885,10 @@ static const vshCmdOptDef opts_echo[] = {
      .type = VSH_OT_ALIAS,
      .help = "string"
     },
+    {.name = "hi",
+     .type = VSH_OT_ALIAS,
+     .help = "string=hello"
+    },
     {.name = "string",
      .type = VSH_OT_ARGV,
      .help = N_("arguments to echo")
@@ -1011,12 +1015,25 @@ vshCmddefOptParse(const vshCmdDef *cmd, uint32_t *opts_need_arg,
         }
         if (opt->type == VSH_OT_ALIAS) {
             size_t j;
+            char *name = (char *)opt->help; /* cast away const */
+            char *p;
+
             if (opt->flags || !opt->help)
                 return -1; /* alias options are tracked by the original name */
+            if ((p = strchr(name, '=')) &&
+                VIR_STRNDUP(name, name, p - name) < 0)
+                return -1;
             for (j = i + 1; cmd->opts[j].name; j++) {
-                if (STREQ(opt->help, cmd->opts[j].name))
+                if (STREQ(name, cmd->opts[j].name) &&
+                    cmd->opts[j].type != VSH_OT_ALIAS)
                     break;
             }
+            if (name != opt->help) {
+                VIR_FREE(name);
+                /* If alias comes with value, replacement must not be bool */
+                if (cmd->opts[j].type == VSH_OT_BOOL)
+                    return -1;
+            }
             if (!cmd->opts[j].name)
                 return -1; /* alias option must map to a later option name */
             continue;
@@ -1049,9 +1066,11 @@ static vshCmdOptDef helpopt = {
 };
 static const vshCmdOptDef *
 vshCmddefGetOption(vshControl *ctl, const vshCmdDef *cmd, const char *name,
-                   uint32_t *opts_seen, int *opt_index)
+                   uint32_t *opts_seen, int *opt_index, char **optstr)
 {
     size_t i;
+    const vshCmdOptDef *ret = NULL;
+    char *alias = NULL;
 
     if (STREQ(name, helpopt.name)) {
         return &helpopt;
@@ -1062,16 +1081,36 @@ vshCmddefGetOption(vshControl *ctl, const vshCmdDef *cmd, const char *name,
 
         if (STREQ(opt->name, name)) {
             if (opt->type == VSH_OT_ALIAS) {
-                name = opt->help;
+                char *value;
+
+                /* Two types of replacements:
+                   opt->help = "string": straight replacement of name
+                   opt->help = "string=value": treat boolean flag as
+                   alias of option and its default value */
+                sa_assert(!alias);
+                if (VIR_STRDUP(alias, opt->help) < 0)
+                    goto cleanup;
+                name = alias;
+                if ((value = strchr(name, '='))) {
+                    *value = '\0';
+                    if (*optstr) {
+                        vshError(ctl, _("invalid '=' after option --%s"),
+                                 opt->name);
+                        goto cleanup;
+                    }
+                    if (VIR_STRDUP(*optstr, value + 1) < 0)
+                        goto cleanup;
+                }
                 continue;
             }
             if ((*opts_seen & (1 << i)) && opt->type != VSH_OT_ARGV) {
                 vshError(ctl, _("option --%s already seen"), name);
-                return NULL;
+                goto cleanup;
             }
             *opts_seen |= 1 << i;
             *opt_index = i;
-            return opt;
+            ret = opt;
+            goto cleanup;
         }
     }
 
@@ -1079,7 +1118,9 @@ vshCmddefGetOption(vshControl *ctl, const vshCmdDef *cmd, const char *name,
         vshError(ctl, _("command '%s' doesn't support option --%s"),
                  cmd->name, name);
     }
-    return NULL;
+cleanup:
+    VIR_FREE(alias);
+    return ret;
 }
 
 static const vshCmdOptDef *
@@ -1845,7 +1886,8 @@ vshCommandParse(vshControl *ctl, vshCommandParser *parser)
                 }
                 /* Special case 'help' to ignore all spurious options */
                 if (!(opt = vshCmddefGetOption(ctl, cmd, tkdata + 2,
-                                               &opts_seen, &opt_index))) {
+                                               &opts_seen, &opt_index,
+                                               &optstr))) {
                     VIR_FREE(optstr);
                     if (STREQ(cmd->name, "help"))
                         continue;
@@ -1875,7 +1917,7 @@ vshCommandParse(vshControl *ctl, vshCommandParser *parser)
                     tkdata = NULL;
                     if (optstr) {
                         vshError(ctl, _("invalid '=' after option --%s"),
-                                opt->name);
+                                 opt->name);
                         VIR_FREE(optstr);
                         goto syntaxError;
                     }
@@ -2226,6 +2268,13 @@ vshTTYIsInterruptCharacter(vshControl *ctl ATTRIBUTE_UNUSED,
 }
 
 
+bool
+vshTTYAvailable(vshControl *ctl)
+{
+    return ctl->istty;
+}
+
+
 int
 vshTTYDisableInterrupt(vshControl *ctl ATTRIBUTE_UNUSED)
 {
@@ -2580,7 +2629,7 @@ vshCloseLogFile(vshControl *ctl)
     }
 }
 
-#ifdef USE_READLINE
+#if WITH_READLINE
 
 /* -----------------
  * Readline stuff
@@ -2699,11 +2748,14 @@ vshReadlineCompletion(const char *text, int start,
     return matches;
 }
 
+# define VIRSH_HISTSIZE_MAX 500000
 
 static int
 vshReadlineInit(vshControl *ctl)
 {
     char *userdir = NULL;
+    int max_history = 500;
+    const char *histsize_str;
 
     /* Allow conditional parsing of the ~/.inputrc file. */
     rl_readline_name = "virsh";
@@ -2712,7 +2764,19 @@ vshReadlineInit(vshControl *ctl)
     rl_attempted_completion_function = vshReadlineCompletion;
 
     /* Limit the total size of the history buffer */
-    stifle_history(500);
+    if ((histsize_str = virGetEnvBlockSUID("VIRSH_HISTSIZE"))) {
+        if (virStrToLong_i(histsize_str, NULL, 10, &max_history) < 0) {
+            vshError(ctl, "%s", _("Bad $VIRSH_HISTSIZE value."));
+            VIR_FREE(userdir);
+            return -1;
+        } else if (max_history > VIRSH_HISTSIZE_MAX || max_history < 0) {
+            vshError(ctl, _("$VIRSH_HISTSIZE value should be between 0 and %d"),
+                     VIRSH_HISTSIZE_MAX);
+            VIR_FREE(userdir);
+            return -1;
+        }
+    }
+    stifle_history(max_history);
 
     /* Prepare to read/write history from/to the $XDG_CACHE_HOME/virsh/history file */
     userdir = virGetUserCacheDirectory();
@@ -2765,7 +2829,7 @@ vshReadline(vshControl *ctl ATTRIBUTE_UNUSED, const char *prompt)
     return readline(prompt);
 }
 
-#else /* !USE_READLINE */
+#else /* !WITH_READLINE */
 
 static int
 vshReadlineInit(vshControl *ctl ATTRIBUTE_UNUSED)
@@ -2799,7 +2863,7 @@ vshReadline(vshControl *ctl, const char *prompt)
     return vshStrdup(ctl, r);
 }
 
-#endif /* !USE_READLINE */
+#endif /* !WITH_READLINE */
 
 static void
 vshDeinitTimer(int timer ATTRIBUTE_UNUSED, void *opaque ATTRIBUTE_UNUSED)
@@ -3026,7 +3090,7 @@ vshShowVersion(vshControl *ctl ATTRIBUTE_UNUSED)
 #ifdef WITH_DTRACE_PROBES
     vshPrint(ctl, " DTrace");
 #endif
-#ifdef USE_READLINE
+#if WITH_READLINE
     vshPrint(ctl, " Readline");
 #endif
 #ifdef WITH_DRIVER_MODULES
@@ -3316,7 +3380,7 @@ main(int argc, char **argv)
             if (ctl->cmdstr == NULL)
                 break;          /* EOF */
             if (*ctl->cmdstr) {
-#if USE_READLINE
+#if WITH_READLINE
                 add_history(ctl->cmdstr);
 #endif
                 if (vshCommandStringParse(ctl, ctl->cmdstr))
